@@ -66,6 +66,7 @@ EXTENSIONS = {
     'gypi': {'text', 'gyp', 'python'},
     'gz': {'binary', 'gzip'},
     'h': {'text', 'header', 'c', 'c++'},
+    'hbs': {'text', 'handlebars'},
     'hcl': {'text', 'hcl'},
     'hh': {'text', 'header', 'c++'},
     'hpp': {'text', 'header', 'c++'},
@@ -108,6 +109,7 @@ EXTENSIONS = {
     'lhs': {'text', 'literate-haskell'},
     'libsonnet': {'text', 'jsonnet'},
     'lidr': {'text', 'idris'},
+    'liquid': {'text', 'liquid'},
     'lr': {'text', 'lektor'},
     'lua': {'text', 'lua'},
     'm': {'text', 'c', 'objective-c'},
@@ -129,6 +131,7 @@ EXTENSIONS = {
     'nims': {'text', 'nim'},
     'nimble': {'text', 'nimble'},
     'nix': {'text', 'nix'},
+    'njk': {'text', 'nunjucks'},
     'otf': {'binary', 'otf'},
     'p12': {'binary', 'p12'},
     'patch': {'text', 'diff'},
